@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'gh'
 
 module GH
@@ -7,30 +9,31 @@ module GH
     attr_accessor :instrumenter
 
     def setup(backend, options)
-      self.instrumenter ||= Travis::EventLogger.method(:notify)              if defined? Travis::EventLogger
+      self.instrumenter ||= Travis::EventLogger.method(:notify) if defined? Travis::EventLogger
       self.instrumenter ||= ActiveSupport::Notifications.method(:instrument) if defined? ActiveSupport::Notifications
       super
     end
 
     def http(verb, url, *)
-      instrument(:http, :verb => verb, :url => url) { super }
+      instrument(:http, verb:, url:) { super }
     end
 
     def load(data)
-      instrument(:load, :data => data) { super }
+      instrument(:load, data:) { super }
     end
 
     def [](key)
-      instrument(:access, :key => key) { super }
+      instrument(:access, key:) { super }
     end
 
     private
 
     def instrument(type, payload = {})
       return yield unless instrumenter
+
       result = nil
-      instrumenter.call("#{type}.gh", payload.merge(:gh => frontend)) { result = yield }
-      return result
+      instrumenter.call("#{type}.gh", payload.merge(gh: frontend)) { result = yield }
+      result
     end
   end
 end
