@@ -1,14 +1,16 @@
+# frozen_string_literal: true
+
 module GH
   class LinkFollower < Wrapper
     wraps GH::Normalizer
     double_dispatch
 
     def modify_hash(hash)
-      hash = super
+      hash = super(hash)
       setup_lazy_loading(hash) if hash['_links']
       hash
-    rescue Exception => error
-      raise Error.new(error, hash)
+    rescue StandardError => e
+      raise Error.new(e, hash)
     end
 
     private
@@ -16,8 +18,8 @@ module GH
     def lazy_load(hash, key)
       link = hash['_links'][key]
       { key => self[link['href']] } if link
-    rescue Exception => error
-      raise Error.new(error, hash)
+    rescue StandardError => e
+      raise Error.new(e, hash)
     end
   end
-end
\ No newline at end of file
+end
