@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'gh'
 
 module GH
@@ -6,15 +8,15 @@ module GH
     wraps GH::Normalizer
     double_dispatch
 
-    def modify_hash(hash, loaded = false)
+    def modify_hash(hash, loaded = false) # rubocop:disable Style/OptionalBooleanParameter
       hash = super(hash)
-      link = hash['_links']['self'] unless loaded or hash['_links'].nil?
+      link = hash['_links']['self'] unless loaded || hash['_links'].nil?
       set_links hash, Addressable::URI.parse(link['href']) if link
       hash
     end
 
     def add(hash, link, name, path = name)
-      hash["_links"][name] ||= { "href" => nested(link, path) }
+      hash['_links'][name] ||= { 'href' => nested(link, path) }
     end
 
     def nested(link, path)
@@ -34,14 +36,14 @@ module GH
         add hash, link, 'starred'
       when %r{^/repos/[^/]+/[^/]+$}
         add hash, link, 'commits', 'git/commits'
-        add hash, link, 'refs',    'git/refs'
-        add hash, link, 'tags',    'git/tags'
+        add hash, link, 'refs', 'git/refs'
+        add hash, link, 'tags', 'git/tags'
         add hash, link, 'issues'
       when %r{^/repos/[^/]+/[^/]+/issues/\d+$}
         add hash, link, 'comments'
         add hash, link, 'events'
       when '/user'
-        add hash, link, 'gists',  '/gists'
+        add hash, link, 'gists', '/gists'
         add hash, link, 'issues', '/issues'
       end
     end
